module Config.Pages.Debate.Arguments.Records.AntiRewilding exposing (..)

import Config.Helpers.Converters exposing (toTitleCase)
import Config.Pages.Debate.Arguments.Types exposing (..)


argumentAntiRewilding : Argument
argumentAntiRewilding =
    { argumentTitle = toTitleCase "Argument Against Rewilding"
    , propositionTitle = "Rewilding sentient animals is immoral."
    , propositionReductio = ""
    , propositionSummary = "I view animal rights as the logical extension of trait-adjusted human rights to non-human animals. I think humans have the right not to be bred into wild circumstances where they're faced with the full brutality of the natural world, and by extension I think non-human animals have this right too."
    , proofLink = "https://www.umsu.de/trees/#(~6x(Px~5~3Qx)),(Pa),(~3Qa~5~3R),(~3R~5Sa)|=(Sa)"
    , argumentCertainty = 10
    , argumentImage = "rewilding"
    , argumentHashtags = []
   
    
    , isNewTabLink = False
    , definitionTable =
        [ { definiendum = "P(x)"
          , definiens = "(x) has negative rights"
          }
        , { definiendum = "Q(x)"
          , definiens = "we should defend (x) from rights violations to any lesser degree than we would tolerate for humans"
          }
        , { definiendum = "R"
          , definiens = "it is permissible to subject animals to conditions that are likely to involve predation, starvation, or death due to environmental exposure to any greater degree than we would tolerate for humans"
          }
        , { definiendum = "S(a)"
          , definiens = "rewilding sentient animals is immoral"
          }
        , { definiendum = "x"
          , definiens = "a being"
          }
        , { definiendum = "a"
          , definiens = "sentient animals"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "For all things, if a being has negative rights, then we should not defend a being from rights violations to any lesser degree than we would tolerate for humans."
                  , notation = "∀x(Px→¬Qx)"
                  }
                , { premise = "Sentient animals have negative rights."
                  , notation = "Pa"
                  }
                , { premise = "If we should not defend sentient animals from rights violations to any lesser degree than we would tolerate for humans, then it is not permissible to subject sentient animals to conditions that are likely to involve predation, starvation, or death due to environmental exposure to any greater degree than we would tolerate for humans."
                  , notation = "¬Qa→¬R"
                  }
                , { premise = "If it is not permissible to subject sentient animals to conditions that are likely to involve predation, starvation, or death due to environmental exposure to any greater degree than we would tolerate for humans, then rewilding sentient animals is immoral."
                  , notation = "¬R→Sa"
                  }
                ]
          , conclusion = "Therefore, rewilding sentient animals is immoral."
          , conclusionNotation = "Sa"
          }
        ]
    }
