module Pages.NotFound_ exposing (Model, Msg, page)

import Config.Data.Identity exposing (pageNames)
import Config.Helpers.Cards.Helpers exposing (cardMaker)
import Config.Helpers.Cards.Types as C
import Config.Helpers.Headers.Helpers exposing (..)
import Config.Helpers.Headers.Types exposing (Header)
import Config.Helpers.Response
    exposing
        ( pageList
        , pageListCenter
        , topLevelContainer
        )
import Effect exposing (Effect)
import Element as E exposing (..)
import Layouts
import Page exposing (Page)
import Route exposing (Route)
import Route.Path
import Shared
import View exposing (View)


page : Shared.Model -> Route () -> Page Model Msg
page shared route =
    Page.new
        { init = init
        , update = update
        , subscriptions = subscriptions
        , view = view shared
        }
        |> Page.withLayout toLayout


toLayout : Model -> Layouts.Layout Msg
toLayout model =
    Layouts.Navbar {}



-- INIT


type alias Model =
    {}


init : () -> ( Model, Effect Msg )
init () =
    ( {}
    , Effect.none
    )



-- UPDATE


type Msg
    = NoOp


update : Msg -> Model -> ( Model, Effect Msg )
update msg model =
    case msg of
        NoOp ->
            ( model
            , Effect.none
            )



-- SUBSCRIPTIONS


subscriptions : Model -> Sub Msg
subscriptions model =
    Sub.none



-- VIEW


view : Shared.Model -> Model -> View Msg
view shared model =
    { title = pageNames.pageNotFound
    , attributes = []
    , element = notFoundContainer shared.device
    }


notFoundContainer : Device -> Element msg
notFoundContainer device =
    topLevelContainer (notFoundList device)


notFoundList : Device -> Element msg
notFoundList device =
    column pageListCenter
        [ case device.class of
            Desktop ->
                none

            BigDesktop ->
                none

            Tablet ->
                case device.orientation of
                    Portrait ->
                        none

                    Landscape ->
                        none

            Phone ->
                case device.orientation of
                    Portrait ->
                        none

                    Landscape ->
                        none
        ]



-- import Config.Data.Identity exposing (pageNames)
-- import Config.Helpers.CardFormat
--     exposing
--         ( cardContentSpacing
--         , cardFormatter
--         , cardMaker
--         , cardTitleMaker
--         , desktopCardMaker
--         , desktopImageBoxSize
--         , desktopImageSize
--         , fieldSpacer
--         , mobileCardMaker
--         , mobileImageBoxSize
--         , mobileImageSize
--         , topLevelBox
--         )
-- import Config.Helpers.Header
--     exposing
--         ( Header
--         , headerMaker
--         )
-- import Config.Helpers.Markdown exposing (..)
-- import Config.Helpers.Response
--     exposing
--         ( pageList
--         , pageListCenter
--         , topLevelContainer
--         )
-- import Effect exposing (Effect)
-- import Element as E exposing (..)
-- import Element.Background as B
-- import Element.Border as D
-- import Element.Font as F
-- import Html exposing (br)
-- import Html.Attributes as H exposing (style)
-- import Layouts
-- import Markdown.Block as Block
-- import Markdown.Html
-- import Markdown.Parser
-- import Markdown.Renderer
-- import Page exposing (Page)
-- import Route exposing (Route)
-- import Route.Path
-- import Shared
-- import View exposing (View)
-- page : Shared.Model -> Route () -> Page Model Msg
-- page shared route =
--     Page.new
--         { init = init
--         , update = update
--         , subscriptions = subscriptions
--         , view = view shared
--         }
--         |> Page.withLayout toLayout
-- toLayout : Model -> Layouts.Layout Msg
-- toLayout model =
--     Layouts.Navbar {}
-- -- INIT
-- type alias Model =
--     { markdown : String }
-- init : () -> ( Model, Effect Msg )
-- init () =
--     ( { markdown = """
-- markdown goes here!
-- """ }
--     , Effect.none
--     )
-- -- UPDATE
-- type Msg
--     = NoOp
--     | UpdateMarkdown String
-- update : Msg -> Model -> ( Model, Effect Msg )
-- update msg model =
--     case msg of
--         NoOp ->
--             ( model, Effect.none )
--         UpdateMarkdown newMarkdown ->
--             ( { model | markdown = newMarkdown }, Effect.none )
-- -- SUBSCRIPTIONS
-- subscriptions : Model -> Sub Msg
-- subscriptions model =
--     Sub.none
-- -- VIEW
-- view : Shared.Model -> Model -> View Msg
-- view shared model =
--     { title = pageNames.pageNotFound
--     , attributes = []
--     , element = notFoundContainer shared.device model
--     }
-- notFoundContainer : Device -> Model -> Element Msg
-- notFoundContainer device model =
--     topLevelContainer (notFoundList device model)
-- notFoundList : Device -> Model -> Element Msg
-- notFoundList device model =
--     column pageListCenter
--         [ case renderMarkdown model.markdown of
--             Ok renderedMarkdown ->
--                 column
--                     [ E.spacing 30
--                     , E.padding 20
--                     , E.width E.fill
--                     , E.centerX
--                     ]
--                     renderedMarkdown
--             Err error ->
--                 E.text error
--         ]
-- renderMarkdown : String -> Result String (List (Element Msg))
-- renderMarkdown markdown =
--     markdown
--         |> Markdown.Parser.parse
--         |> Result.mapError (\error -> error |> List.map Markdown.Parser.deadEndToString |> String.join "\n")
--         |> Result.andThen (Markdown.Renderer.render elmUiRenderer)
